pub struct TestSymbols;Expand description
A set of symbols where every symbol is either whitespace ( ) or an empty string.
Example
StmtKind::Var
declarations=
Var
name: "x"
kind: Let
initializer: ExprKind::Binary
op: Add
left: Lit
token: "1"
value: LitValue::Integer(1)
right: Lit
token: "2.3"
value: LitValue::Float(2.3)
n_uses: 0
StmtKind::Print
value: ExprKind::Comma
operands=
Lit
token: "\"hello, world!\""
value: LitValue::Str("hello, world!")
ExprKind::Variable
name: "x"Trait Implementations
Sourceimpl Symbols for TestSymbols
impl Symbols for TestSymbols
Sourcefn description(&self) -> &'static str
fn description(&self) -> &'static str
Used by the debug impl for
&dyn Symbols.Sourcefn horizontal_bar(&self) -> &'static str
fn horizontal_bar(&self) -> &'static str
The horizontal bar symbol used to draw horizontal tree branches, e.g.
─.Sourcefn vertical_bar(&self) -> &'static str
fn vertical_bar(&self) -> &'static str
The vertical bar symbol used to draw the tree trunks of the tree and its subtrees, e.g.
│.Sourcefn right_branch(&self) -> &'static str
fn right_branch(&self) -> &'static str
A piece of trunk with a branch to the right, e.g.
├.Sourcefn left_upper_corner(&self) -> &'static str
fn left_upper_corner(&self) -> &'static str
The symbol for left upper corners, e.g.
╭.Sourcefn left_bottom_corner(&self) -> &'static str
fn left_bottom_corner(&self) -> &'static str
The symbol for left bottom corners, e.g.
╰.Sourcefn right_upper_corner(&self) -> &'static str
fn right_upper_corner(&self) -> &'static str
The symbol for right upper corners, e.g.
╮.Sourcefn right_bottom_corner(&self) -> &'static str
fn right_bottom_corner(&self) -> &'static str
The symbol for right bottom corners, e.g.
╯.Sourcefn missing_items_symbol(&self) -> &'static str
fn missing_items_symbol(&self) -> &'static str
The symbol to display when a list of items is empty, e.g.
✕.Sourcefn item_list_symbol(&self) -> &'static str
fn item_list_symbol(&self) -> &'static str
The symbol to display when a list of items is non-empty, e.g.
↓.Auto Trait Implementations
impl Freeze for TestSymbols
impl RefUnwindSafe for TestSymbols
impl Send for TestSymbols
impl Sync for TestSymbols
impl Unpin for TestSymbols
impl UnsafeUnpin for TestSymbols
impl UnwindSafe for TestSymbols